<?php 

class WPNS_SETTING_PAGE{
	
	//Holds the values to be used in the fields callbacks
  private $_options;
	private $_default_settings;

  //Start up
	public function __construct($default_settings){
		add_action( 'admin_menu', array( $this, 'add_plugin_page' ) );
    add_action( 'admin_init', array( $this, 'page_init' ) );
		$this->_default_settings = $default_settings;  
		$this->_options = get_option( 'wpns_settings_preview' );	
  }

  //Add options page
  public function add_plugin_page(){
		add_options_page('Page navi slider', 'Page navi slider', 'manage_options', 'wpns_settings_admin', array( $this, 'create_admin_page' ));
		
		wp_enqueue_style ('jquery-ui-style', plugins_url('../style/jquery-ui.css', __FILE__));
		wp_enqueue_script('accordion-style',  plugins_url('../js/accordion.js', __FILE__),	array( 'jquery', 'jquery-ui-slider', 'jquery-ui-accordion' ),true	);
		
		wp_register_style( 'page_navi_slider_style', plugins_url('../style/page-navi-slider.css', __FILE__) );
		wp_enqueue_style( 'page_navi_slider_style' );
		if(ereg('MSIE 7',$_SERVER['HTTP_USER_AGENT'])){
			wp_register_style('page_navi_slider_styleIE', plugins_url('../style/page-navi-slider.ie.css', __FILE__) );
			wp_enqueue_style('page_navi_slider_styleIE' );
		} 
		
		wp_enqueue_script('page-navi-slider-script',  plugins_url('../js/page-navi-slider.min.js', __FILE__),	array( 'jquery', 'jquery-ui-slider' ),true	);
		wp_enqueue_script('jQueryUiTouch',  plugins_url('../js/jquery.ui.touch-punch.min.js', __FILE__),	array( 'jquery' ), true);
		wp_enqueue_script('jscolor',  plugins_url('../js/jsColor/jscolor.min.js', __FILE__),	array( 'jquery' ));
  }

  //Options page callback
  public function create_admin_page(){

	?>

	<div class="wrap">
		<?php screen_icon(); ?>
		<h2>Page navi slider <span style="font-size:small"><?php echo wpns_version(); ?></span></h2> 
		
		<div class="wpns_settings_page">
    <h3><?php _e('Preview','page-navi-slider');?></h3> 	
		<?php require_once(dirname( __FILE__ ) . '/preview.php'); ?>
		<h3><?php _e('Settings','page-navi-slider');?></h3> 
		
    <form method="post" action="options.php">
			<table class="wpns_setting_buttons"><tr>
				<td><?php submit_button(__('Preview','page-navi-slider'),'reset','preview'); ?></td>
				<td><?php submit_button(__('Revert','page-navi-slider'),'reset','revert',true, $this->_options['wpns_revert_disabled'] ); ?></td>
				<td><?php submit_button(__('Save changes','page-navi-slider'),'primary','submit',true,$this->_options['wpns_revert_disabled']); ?>
				</td>
				<td><?php submit_button(__('Reset to default','page-navi-slider'),'reset','reset'); ?>
				</td>
			</tr></table>
			<?php
				echo '<div id="wpns_accordion">';
				settings_fields( 'wpns_settings_preview' );
				$this->wpns_do_settings_sections( 'wpns_settings_admin' );
				echo '</div>';
			?>
		</form>
		</div>
	</div>

	<?php
	}

	
	//Adaptated do_settings_sections function 
	//Section info is included in the table
	//to be included in the jQuery accordions panels
	function wpns_do_settings_sections( $page ) {
		global $wp_settings_sections, $wp_settings_fields;
		if ( ! isset( $wp_settings_sections ) || !isset( $wp_settings_sections[$page] ) )		return;
		
		foreach ( (array) $wp_settings_sections[$page] as $section ) {
			if ( $section['title'] ) 	echo "<h3>{$section['title']}</h3>\n";
			if ( ! isset( $wp_settings_fields ) || !isset( $wp_settings_fields[$page] ) || !isset( $wp_settings_fields[$page][$section['id']] ) )	continue;
			echo '<table class="form-table wpns_setting_table">';
			if ( $section['callback'] ){
				echo "<tr><td colspan=2>";
				call_user_func( $section['callback'], $section );
				echo "</td></tr>";
			};
			do_settings_fields( $page, $section['id'] );
			echo '</table>';
		}
	}
	
	//Register and add settings
	public function page_init(){        
		register_setting('wpns_settings_preview','wpns_settings_preview', array( $this, 'sanitize' ));
		//sections
		add_settings_section('wpns_preview_section',__('Preview options','page-navi-slider'), array( $this, 'print_preview_info' ), 'wpns_settings_admin');
		add_settings_section('wpns_general_section',__('General settings','page-navi-slider'), array( $this, 'print_general_info' ), 'wpns_settings_admin');
		add_settings_section('wpns_caption_section',__('Caption','page-navi-slider'), array( $this, 'print_caption_info' ), 'wpns_settings_admin');
		add_settings_section('wpns_font_section',__('Fonts','page-navi-slider'), array( $this, 'print_font_info' ), 'wpns_settings_admin');
		add_settings_section('wpns_color_section',__('Colors','page-navi-slider'), array( $this, 'print_color_info' ), 'wpns_settings_admin');
		add_settings_section('wpns_border_section',__('Borders','page-navi-slider'), array( $this, 'print_border_info' ), 'wpns_settings_admin');
		add_settings_section('wpns_autodisplay_section',__('Auto display','page-navi-slider')." <b> - ".__('CAUTION !','page-navi-slider')."</b>", array( $this, 'print_autodisplay_info' ), 'wpns_settings_admin');
		//fields - Preview
		add_settings_field('wpns_preview_background_color',__('Background color','page-navi-slider'),array( $this, 'wpns_preview_background_color_callback' ),'wpns_settings_admin','wpns_preview_section');      
		add_settings_field('wpns_preview_pages',__('Number of pages','page-navi-slider'),array( $this, 'wpns_preview_pages_callback' ),'wpns_settings_admin','wpns_preview_section');      
		add_settings_field('wpns_preview_current',__('Current page','page-navi-slider'),array( $this, 'wpns_preview_current_callback' ),'wpns_settings_admin','wpns_preview_section');      
		//fields - General
		add_settings_field('wpns_margin',__('Wrapper margin','page-navi-slider'),array( $this, 'wpns_margin_callback' ),'wpns_settings_admin','wpns_general_section');      
		add_settings_field('wpns_padding',__('Wrapper padding','page-navi-slider'),array( $this, 'wpns_padding_callback' ),'wpns_settings_admin','wpns_general_section');      
		add_settings_field('wpns_display_if_one_page',__('Display even if there is only one page','page-navi-slider'),array( $this, 'wpns_display_if_one_page_callback' ),'wpns_settings_admin','wpns_general_section');      
		add_settings_field('wpns_align',__('Alignment','page-navi-slider'),array( $this, 'wpns_align_callback' ),'wpns_settings_admin','wpns_general_section');		
		add_settings_field('wpns_pn_width',__('Page numbers width','page-navi-slider'),array( $this, 'wpns_pn_width_callback' ),'wpns_settings_admin','wpns_general_section');      
		add_settings_field('wpns_spacing',__('Spacing between page numbers','page-navi-slider'),array( $this, 'wpns_spacing_callback' ),'wpns_settings_admin','wpns_general_section');      
		add_settings_field('wpns_show_total',__('Show total pages in the current one','page-navi-slider'),array( $this, 'wpns_show_total_callback' ),'wpns_settings_admin','wpns_general_section');      
		//fields - Fonts
		add_settings_field('wpns_caption_font',__('Caption','page-navi-slider'),array( $this, 'wpns_caption_font_callback' ),'wpns_settings_admin','wpns_font_section');      
		add_settings_field('wpns_page_font',__('Page numbers','page-navi-slider'),array( $this, 'wpns_page_font_callback' ),'wpns_settings_admin','wpns_font_section');      
		add_settings_field('wpns_current_font',__('Current page','page-navi-slider'),array( $this, 'wpns_current_font_callback' ),'wpns_settings_admin','wpns_font_section');      
		add_settings_field('wpns_hover_font',__('On hover','page-navi-slider'),array( $this, 'wpns_hover_font_callback' ),'wpns_settings_admin','wpns_font_section');      
		//fields - Title
		add_settings_field('wpns_caption_text',__('Text<br><small>%%NUMBER%% : current page</small><br><small>%%TOTAL%% : total pages<small>','page-navi-slider'),array( $this, 'wpns_caption_text_callback' ),'wpns_settings_admin','wpns_caption_section');      
		add_settings_field('wpns_caption_position',__('Position','page-navi-slider'),array( $this, 'wpns_caption_position_callback' ),'wpns_settings_admin','wpns_caption_section');      
		add_settings_field('wpns_caption_alignment',__('Alignment','page-navi-slider'),array( $this, 'wpns_caption_alignment_callback' ),'wpns_settings_admin','wpns_caption_section');      
		//fields - Colors
		add_settings_field('wpns_caption_color',__('Caption','page-navi-slider'),array( $this, 'wpns_caption_color_callback' ),'wpns_settings_admin','wpns_color_section');   
		add_settings_field('wpns_page_fore_color',__('Page numbers','page-navi-slider'),array( $this, 'wpns_page_fore_color_callback' ),'wpns_settings_admin','wpns_color_section');   
		add_settings_field('wpns_page_back_color',__('Page numbers background','page-navi-slider'),array( $this, 'wpns_page_back_color_callback' ),'wpns_settings_admin','wpns_color_section');    
		add_settings_field('wpns_current_fore_color',__('Current page','page-navi-slider'),array( $this, 'wpns_current_fore_color_callback' ),'wpns_settings_admin','wpns_color_section');   
		add_settings_field('wpns_current_back_color',__('Current page background','page-navi-slider'),array( $this, 'wpns_current_back_color_callback' ),'wpns_settings_admin','wpns_color_section');    
		add_settings_field('wpns_hover_fore_color',__('On hover','page-navi-slider'),array( $this, 'wpns_hover_fore_color_callback' ),'wpns_settings_admin','wpns_color_section');   
		add_settings_field('wpns_hover_back_color',__('On hover background','page-navi-slider'),array( $this, 'wpns_hover_back_color_callback' ),'wpns_settings_admin','wpns_color_section');    
		add_settings_field('wpns_slider_color',__('Slider','page-navi-slider'),array( $this, 'wpns_slider_color_callback' ),'wpns_settings_admin','wpns_color_section');
		add_settings_field('wpns_cursor_color',__('Handle','page-navi-slider'),array( $this, 'wpns_cursor_color_callback' ),'wpns_settings_admin','wpns_color_section');    
		//fields - Borders
		add_settings_field('wpns_radius',__('Radius <small>(<b>em</b>/px)</small>','page-navi-slider'),array( $this, 'wpns_radius_callback' ),'wpns_settings_admin','wpns_border_section');      
		add_settings_field('wpns_page_border',__('Page numbers','page-navi-slider'),array( $this, 'wpns_page_border_callback' ),'wpns_settings_admin','wpns_border_section');      
		add_settings_field('wpns_current_border',__('Current page','page-navi-slider'),array( $this, 'wpns_current_border_callback' ),'wpns_settings_admin','wpns_border_section');      
		add_settings_field('wpns_hover_border',__('On hover','page-navi-slider'),array( $this, 'wpns_hover_border_callback' ),'wpns_settings_admin','wpns_border_section');      
		add_settings_field('wpns_slider_border',__('Slider','page-navi-slider'),array( $this, 'wpns_slider_border_callback' ),'wpns_settings_admin','wpns_border_section');      
		add_settings_field('wpns_cursor_border',__('Cursor','page-navi-slider'),array( $this, 'wpns_cursor_border_callback' ),'wpns_settings_admin','wpns_border_section');      
		//fields - Auto display
		add_settings_field('wpns_auto_display',__('Display in footer','page-navi-slider'),array( $this, 'wpns_auto_display_callback' ),'wpns_settings_admin','wpns_autodisplay_section');      
		add_settings_field('wpns_auto_display_position',__('Location','page-navi-slider'),array( $this, 'wpns_auto_display_position_callback' ),'wpns_settings_admin','wpns_autodisplay_section');      
		
		}

	 /*Sanitize each setting field as needed
		 @param array $input Contains all settings fields as array keys*/
	public function sanitize( $input ){
		//if( !is_numeric( $input['id_number'] ) ) $input['id_number'] = '';  
		//if( !empty( $input['title'] ) ) $input['title'] = sanitize_text_field( $input['title'] );
		if($input['wpns_caption_font_size']==''){$input['wpns_caption_font_size']='1em';}
		if($input['wpns_caption_font_lineheight']==''){$input['wpns_caption_font_lineheight']='1em';}
		if($input['wpns_caption_font_family']==''){$input['wpns_caption_font_family']='Arial,Helvetica,Sans-Serif';}
		$input['wpns_caption_font']=$input['wpns_caption_font_style'].' '.$input['wpns_caption_font_variant'].' '.$input['wpns_caption_font_weight'].' '.$input['wpns_caption_font_size'].'/'.$input['wpns_caption_font_lineheight'].' '.$input['wpns_caption_font_family'];
		
		if($input['wpns_page_font_size']==''){$input['wpns_page_font_size']='1em';}
		if($input['wpns_page_font_lineheight']==''){$input['wpns_page_font_lineheight']='1em';}
		if($input['wpns_page_font_family']==''){$input['wpns_page_font_family']='Arial,Helvetica,Sans-Serif';}
		$input['wpns_page_font']=$input['wpns_page_font_style'].' '.$input['wpns_page_font_variant'].' '.$input['wpns_page_font_weight'].' '.$input['wpns_page_font_size'].'/'.$input['wpns_page_font_lineheight'].' '.$input['wpns_page_font_family'];
		
		if($input['wpns_current_font_size']==''){$input['wpns_current_font_size']='1em';}
		if($input['wpns_current_font_lineheight']==''){$input['wpns_current_font_lineheight']='1em';}
		if($input['wpns_current_font_family']==''){$input['wpns_current_font_family']='Arial,Helvetica,Sans-Serif';}
		$input['wpns_current_font']=$input['wpns_current_font_style'].' '.$input['wpns_current_font_variant'].' '.$input['wpns_current_font_weight'].' '.$input['wpns_current_font_size'].'/'.$input['wpns_current_font_lineheight'].' '.$input['wpns_current_font_family'];
	
		if($input['wpns_hover_font_size']==''){$input['wpns_hover_font_size']='1em';}
		if($input['wpns_hover_font_lineheight']==''){$input['wpns_hover_font_lineheight']='1em';}
		if($input['wpns_hover_font_family']==''){$input['wpns_hover_font_family']='Arial,Helvetica,Sans-Serif';}
		$input['wpns_hover_font']=$input['wpns_hover_font_style'].' '.$input['wpns_hover_font_variant'].' '.$input['wpns_hover_font_weight'].' '.$input['wpns_hover_font_size'].'/'.$input['wpns_hover_font_lineheight'].' '.$input['wpns_hover_font_family'];	
		
		if (isset($_POST['preview'])){
			add_settings_error('', 'wpns_setting_message', _('PREVIEW ONLY - Click on &laquo;Save changes&raquo; to apply settings.','page-navi-slider'), 'error');
			$input['wpns_revert_disabled']='';
		}
		if (isset($_POST['revert'])){
			add_settings_error('', 'wpns_setting_message', _('Former settings loaded.','page-navi-slider'), 'updated');
			$input=$this->_default_settings;
			$input=get_option('wpns_settings',$input);
			$input['wpns_revert_disabled']='disabled';
		}
		if (isset($_POST['submit'])){
			add_settings_error('', 'wpns_setting_message', _('Settings saved.','page-navi-slider'), 'updated');
			$input['wpns_revert_disabled']='disabled';
			update_option('wpns_settings',$input);
		}
		if (isset($_POST['reset'])){
			add_settings_error('', 'wpns_setting_message', _('Default settings loaded - PREVIEW ONLY - Click on &laquo;Save changes&raquo; to apply settings.','page-navi-slider'), 'error');
			$input=$this->_default_settings;
			$input['wpns_revert_disabled']='';
		}
		return $input;
	}

	//Print the Section text
	public function print_preview_info(){
		echo "<span class='wpns_setting_small'>";
		_e('These settins only affect the preview on that page; ','page-navi-slider');
		_e('they do not have any impact on the plugin itself.','page-navi-slider');
		echo "<br/>";
		_e('The dotted border is just for preview purpose and will not be displayed on your page.','page-navi-slider');
		echo "</span>";
	}
	
	public function print_general_info(){
		echo "<span class='wpns_setting_small'>";
		_e('Use CSS shorthand for margin and padding; Syntax : top right bottom left.','page-navi-slider');
		echo "<br/>px / em / %";
		_e('can be used and mixed.','page-navi-slider');
		echo "<br/><b>";
		_e('The slider is shown only if the number of pages exceeds the plugin widht.','page-navi-slider');
		echo "</b><br/>";
		_e('Example : Set the margin to &laquo;1em 20% 0 20%&raquo;','page-navi-slider');
		echo "<br/>";
		_e('The plugin will use 60% of the available width and will apply a top margin of 1 em.','page-navi-slider');
		echo "</span>";
	}
	public function print_caption_info(){}
	
	public function print_font_info(){
		echo "<span class='wpns_setting_small'>";
		_e('CSS shorthand; Syntax : font-weight font-style font-variant font-size line-height font-family.','page-navi-slider');
		echo "<br/>";
		_e('Choosing a bigger size for <b>Current</b> and/or <b>On hover</b> will occur a <b>zoom effect</b>.','page-navi-slider');
		echo "<br/>";
		echo "</span>";
	}
	public function print_color_info(){
		echo "<span class='wpns_setting_small'>";
		_e('Let empty to use the parent element color.','page-navi-slider');
		echo "<br/>";
		_e('<b>Advanced styles allowed</b> - e.g. radial-gradient(ellipse at center, rgba(0,0,0,0.65) 0%,rgba(0,0,0,0) 100%)','page-navi-slider');
		echo "<br/>";
		_e('<b>transparent</b> allowed.','page-navi-slider');
		echo "<br/>";
		echo "</span>";
	}
	public function print_border_info(){
		echo "<span class='wpns_setting_small'>";
		_e('Use CSS shorthand; Syntax : thickness style color.','page-navi-slider');
		echo "<br/>";
		_e('Let empty for no border.','page-navi-slider');
		echo "<br/>";
		_e('Choosing a color will generate a 1 px border; can be modified later.','page-navi-slider');
		echo "<br/>";
		_e('<b>High radius</b> will occur in <b>surrounded</b> page nubers.','page-navi-slider');
		echo "<br/>";
		echo "</span>";
	}
	
	public function print_autodisplay_info(){
		echo "<span class='wpns_setting_small'><b>";
		_e('This feature depends on your theme and could return unexpected results.','page-navi-slider');
		echo "</b><br/>";
		_e('Prefer manual installation by adding the following code in your theme templates where you want the plugin to be displayed:','page-navi-slider');
		echo "<br/><b>";
		echo "&lt;php if(function_exists('page_navi_slider')){page_navi_slider()}; ?&gt;";
		echo "</b></span>";
	}

	public function print_font_fields($name,$value){
		//echo $name;
	}
	


	//Get the settings option array and print one of its values
	//Preview	
	public function wpns_preview_background_color_callback(){
		printf('<input type="text" class="color {hash:true, adjust:false, required:false}" id="wpns_preview_background_color" name="wpns_settings_preview[wpns_preview_background_color]" value="%s" />',esc_attr( $this->_options['wpns_preview_background_color']));
	}
	public function wpns_preview_pages_callback(){printf('<input type="text" id="wpns_preview_pages" name="wpns_settings_preview[wpns_preview_pages]" value="%s" />',esc_attr( $this->_options['wpns_preview_pages']));}
	public function wpns_preview_current_callback(){printf('<input type="text" id="wpns_preview_current" name="wpns_settings_preview[wpns_preview_current]" value="%s" />',esc_attr( $this->_options['wpns_preview_current']));}
	//General	
	public function wpns_margin_callback(){printf('<input type="text" id="wpns_margin" name="wpns_settings_preview[wpns_margin]" value="%s" />',esc_attr( $this->_options['wpns_margin']));}
	public function wpns_padding_callback(){printf('<input type="text" id="wpns_padding" name="wpns_settings_preview[wpns_padding]" value="%s" />',esc_attr( $this->_options['wpns_padding']));}
	public function wpns_display_if_one_page_callback(){printf('<input type="checkbox" id="wpns_display_if_one_page" name="wpns_settings_preview[wpns_display_if_one_page]" value="1"' . checked( 1,$this->_options['wpns_display_if_one_page'],false) . '/>',esc_attr( $this->_options['wpns_display_if_one_page']));}
	public function wpns_align_callback(){
		printf('<select type="text" id="wpns_align" name="wpns_settings_preview[wpns_align]" value="%s" />',esc_attr( $this->_options['wpns_align']));
		printf('<option value="left"'.selected( 'left',$this->_options['wpns_align'],false).'>left</option>');
		printf('<option value="center"'.selected( 'center',$this->_options['wpns_align'],false).'>center</option>');
		printf('<option value="right"'.selected( 'right',$this->_options['wpns_align'],false).'>right</option>');
		printf('</select>');
	}
	public function wpns_pn_width_callback(){printf('<input type="text" id="wpns_pn_width" name="wpns_settings_preview[wpns_pn_width]" value="%s" />',esc_attr( $this->_options['wpns_pn_width']));}
	public function wpns_spacing_callback(){printf('<input type="text" id="wpns_spacing" name="wpns_settings_preview[wpns_spacing]" value="%s" />',esc_attr( $this->_options['wpns_spacing']));}
	public function wpns_show_total_callback(){printf('<input type="checkbox" id="wpns_show_total" name="wpns_settings_preview[wpns_show_total]" value="1"' . checked( 1,$this->_options['wpns_show_total'],false) . '/>',esc_attr( $this->_options['wpns_show_total']));}
	//Caption
	public function wpns_caption_text_callback(){printf('<input style="width : 100%%" type="text" id="wpns_caption_text" name="wpns_settings_preview[wpns_caption_text]" value="%s" />',esc_attr( $this->_options['wpns_caption_text']));}
	public function wpns_caption_position_callback(){
		printf('<select type="text" id="wpns_caption_position" name="wpns_settings_preview[wpns_caption_position]" value="%s" />',esc_attr( $this->_options['wpns_caption_position']));
		printf('<option value="top"'.selected( 'top',$this->_options['wpns_caption_position'],false).'>top</option>');
		printf('<option value="bottom"'.selected( 'bottom',$this->_options['wpns_caption_position'],false).'>bottom</option>');
		printf('</select>');
	}
	public function wpns_caption_alignment_callback(){
		printf('<select type="text" id="wpns_caption_alignment" name="wpns_settings_preview[wpns_caption_alignment]" value="%s" />',esc_attr( $this->_options['wpns_caption_alignment']));
		printf('<option value="left"'.selected( 'left',$this->_options['wpns_caption_alignment'],false).'>left</option>');
		printf('<option value="center"'.selected( 'center',$this->_options['wpns_caption_alignment'],false).'>center</option>');
		printf('<option value="right"'.selected( 'right',$this->_options['wpns_caption_alignment'],false).'>right</option>');
		printf('</select>');
	}
	//Fonts
	public function wpns_caption_font_callback(){
		$tab=explode(' ', $this->_options['wpns_caption_font']);
		$tab2=explode('/', $tab[3]);
		printf('<select style="width : 6em" type="text" id="wpns_caption_font_style" name="wpns_settings_preview[wpns_caption_font_style]" value="%s" />',esc_attr( $tab[0]));
		printf('<option value="normal"'.selected( 'normal',$tab[0],false).'>normal</option>');
		printf('<option value="italic"'.selected( 'italic',$tab[0],false).'>italic</option>');
		printf('<option value="oblique"'.selected( 'oblique',$tab[0],false).'>oblique</option>');
		printf('</select>');
		printf('<select style="width : 8em" type="text" id="wpns_caption_font_variant" name="wpns_settings_preview[wpns_caption_font_variant]" value="%s" />',esc_attr( $tab[1]));
		printf('<option value="normal"'.selected( 'normal',$tab[1],false).'>normal</option>');
		printf('<option value="small-caps"'.selected( 'small-caps',$tab[1],false).'>small-caps</option>');
		printf('</select>');
		printf('<select style="width : 6em" type="text" id="wpns_caption_font_weight" name="wpns_settings_preview[wpns_caption_font_weight]" value="%s" />',esc_attr( $tab[2]));
		printf('<option value="normal"'.selected( 'normal',$tab[2],false).'>normal</option>');
		printf('<option value="bold"'.selected( 'bold',$tab[2],false).'>bold</option>');
		printf('<option value="bolder"'.selected( 'bolder',$tab[2],false).'>bolder</option>');
		printf('<option value="lighter"'.selected( 'lighter',$tab[2],false).'>lighter</option>');
		printf('<option value="inherit"'.selected( 'inherit',$tab[2],false).'>inherit</option>');
		printf('</select><br/>');
		printf('<input style="width : 6em; text-align : right;" type="text" id="wpns_caption_font_size" name="wpns_settings_preview[wpns_caption_font_size]" value="%s" />',esc_attr($tab2[0]));
		printf('/').
		printf('<input style="width : 6em" type="text" id="wpns_caption_font_lineheight" name="wpns_settings_preview[wpns_caption_font_lineheight]" value="%s" />',esc_attr($tab2[1]));
		printf('<input style="width : 18em" type="text" id="wpns_caption_font_family" name="wpns_settings_preview[wpns_caption_font_family]" value="%s" />',esc_attr($tab[4]));
	}
	public function wpns_page_font_callback(){
		$tab=explode(' ', $this->_options['wpns_page_font']);
		$tab2=explode('/', $tab[3]);
		printf('<select style="width : 6em" type="text" id="wpns_page_font_style" name="wpns_settings_preview[wpns_page_font_style]" value="%s" />',esc_attr( $tab[0]));
		printf('<option value="normal"'.selected( 'normal',$tab[0],false).'>normal</option>');
		printf('<option value="italic"'.selected( 'italic',$tab[0],false).'>italic</option>');
		printf('<option value="oblique"'.selected( 'oblique',$tab[0],false).'>oblique</option>');
		printf('</select>');
		printf('<select style="width : 8em" type="text" id="wpns_page_font_variant" name="wpns_settings_preview[wpns_page_font_variant]" value="%s" />',esc_attr( $tab[1]));
		printf('<option value="normal"'.selected( 'normal',$tab[1],false).'>normal</option>');
		printf('<option value="small-caps"'.selected( 'small-caps',$tab[1],false).'>small-caps</option>');
		printf('</select>');
		printf('<select style="width : 6em" type="text" id="wpns_page_font_weight" name="wpns_settings_preview[wpns_page_font_weight]" value="%s" />',esc_attr( $tab[2]));
		printf('<option value="normal"'.selected( 'normal',$tab[2],false).'>normal</option>');
		printf('<option value="bold"'.selected( 'bold',$tab[2],false).'>bold</option>');
		printf('<option value="bolder"'.selected( 'bolder',$tab[2],false).'>bolder</option>');
		printf('<option value="lighter"'.selected( 'lighter',$tab[2],false).'>lighter</option>');
		printf('<option value="inherit"'.selected( 'inherit',$tab[2],false).'>inherit</option>');
		printf('</select><br/>');
		printf('<input style="width : 6em; text-align : right;" type="text" id="wpns_page_font_size" name="wpns_settings_preview[wpns_page_font_size]" value="%s" />',esc_attr($tab2[0]));
		printf('/').
		printf('<input style="width : 6em" type="text" id="wpns_page_font_lineheight" name="wpns_settings_preview[wpns_page_font_lineheight]" value="%s" />',esc_attr($tab2[1]));
		printf('<input style="width : 18em" type="text" id="wpns_page_font_family" name="wpns_settings_preview[wpns_page_font_family]" value="%s" />',esc_attr($tab[4]));	
	}
	public function wpns_current_font_callback(){
		$tab=explode(' ', $this->_options['wpns_current_font']);
		$tab2=explode('/', $tab[3]);
		printf('<select style="width : 6em" type="text" id="wpns_current_font_style" name="wpns_settings_preview[wpns_current_font_style]" value="%s" />',esc_attr( $tab[0]));
		printf('<option value="normal"'.selected( 'normal',$tab[0],false).'>normal</option>');
		printf('<option value="italic"'.selected( 'italic',$tab[0],false).'>italic</option>');
		printf('<option value="oblique"'.selected( 'oblique',$tab[0],false).'>oblique</option>');
		printf('</select>');
		printf('<select style="width : 8em" type="text" id="wpns_current_font_variant" name="wpns_settings_preview[wpns_current_font_variant]" value="%s" />',esc_attr( $tab[1]));
		printf('<option value="normal"'.selected( 'normal',$tab[1],false).'>normal</option>');
		printf('<option value="small-caps"'.selected( 'small-caps',$tab[1],false).'>small-caps</option>');
		printf('</select>');
		printf('<select style="width : 6em" type="text" id="wpns_current_font_weight" name="wpns_settings_preview[wpns_current_font_weight]" value="%s" />',esc_attr( $tab[2]));
		printf('<option value="normal"'.selected( 'normal',$tab[2],false).'>normal</option>');
		printf('<option value="bold"'.selected( 'bold',$tab[2],false).'>bold</option>');
		printf('<option value="bolder"'.selected( 'bolder',$tab[2],false).'>bolder</option>');
		printf('<option value="lighter"'.selected( 'lighter',$tab[2],false).'>lighter</option>');
		printf('<option value="inherit"'.selected( 'inherit',$tab[2],false).'>inherit</option>');
		printf('</select><br/>');
		printf('<input style="width : 6em; text-align : right;" type="text" id="wpns_current_font_size" name="wpns_settings_preview[wpns_current_font_size]" value="%s" />',esc_attr($tab2[0]));
		printf('/').
		printf('<input style="width : 6em" type="text" id="wpns_current_font_lineheight" name="wpns_settings_preview[wpns_current_font_lineheight]" value="%s" />',esc_attr($tab2[1]));
		printf('<input style="width : 18em" type="text" id="wpns_current_font_family" name="wpns_settings_preview[wpns_current_font_family]" value="%s" />',esc_attr($tab[4]));	
		}
	public function wpns_hover_font_callback(){
		$tab=explode(' ', $this->_options['wpns_hover_font']);
		$tab2=explode('/', $tab[3]);
		printf('<select style="width : 6em" type="text" id="wpns_hover_font_style" name="wpns_settings_preview[wpns_hover_font_style]" value="%s" />',esc_attr( $tab[0]));
		printf('<option value="normal"'.selected( 'normal',$tab[0],false).'>normal</option>');
		printf('<option value="italic"'.selected( 'italic',$tab[0],false).'>italic</option>');
		printf('<option value="oblique"'.selected( 'oblique',$tab[0],false).'>oblique</option>');
		printf('</select>');
		printf('<select style="width : 8em" type="text" id="wpns_hover_font_variant" name="wpns_settings_preview[wpns_hover_font_variant]" value="%s" />',esc_attr( $tab[1]));
		printf('<option value="normal"'.selected( 'normal',$tab[1],false).'>normal</option>');
		printf('<option value="small-caps"'.selected( 'small-caps',$tab[1],false).'>small-caps</option>');
		printf('</select>');
		printf('<select style="width : 6em" type="text" id="wpns_hover_font_weight" name="wpns_settings_preview[wpns_hover_font_weight]" value="%s" />',esc_attr( $tab[2]));
		printf('<option value="normal"'.selected( 'normal',$tab[2],false).'>normal</option>');
		printf('<option value="bold"'.selected( 'bold',$tab[2],false).'>bold</option>');
		printf('<option value="bolder"'.selected( 'bolder',$tab[2],false).'>bolder</option>');
		printf('<option value="lighter"'.selected( 'lighter',$tab[2],false).'>lighter</option>');
		printf('<option value="inherit"'.selected( 'inherit',$tab[2],false).'>inherit</option>');
		printf('</select><br/>');
		printf('<input style="width : 6em; text-align : right;" type="text" id="wpns_hover_font_size" name="wpns_settings_preview[wpns_hover_font_size]" value="%s" />',esc_attr($tab2[0]));
		printf('/').
		printf('<input style="width : 6em" type="text" id="wpns_hover_font_lineheight" name="wpns_settings_preview[wpns_hover_font_lineheight]" value="%s" />',esc_attr($tab2[1]));
		printf('<input style="width : 18em" type="text" id="wpns_hover_font_family" name="wpns_settings_preview[wpns_hover_font_family]" value="%s" />',esc_attr($tab[4]));	
	}
	//Colors
	public function wpns_caption_color_callback(){printf('<input style="width: 100%%" class="color {hash:true, adjust:false, required:false}" type="text" id="wpns_caption_color" name="wpns_settings_preview[wpns_caption_color]" value="%s" />',esc_attr( $this->_options['wpns_caption_color']));}
	public function wpns_page_fore_color_callback(){printf('<input style="width: 100%%" class="color {hash:true, adjust:false, required:false}" type="text" id="wpns_page_fore_color" name="wpns_settings_preview[wpns_page_fore_color]" value="%s" />',esc_attr( $this->_options['wpns_page_fore_color']));}
	public function wpns_page_back_color_callback(){printf('<input style="width: 100%%" class="color {hash:true, adjust:false, required:false}" type="text" id="wpns_page_back_color" name="wpns_settings_preview[wpns_page_back_color]" value="%s" />',esc_attr( $this->_options['wpns_page_back_color']));}
	public function wpns_current_fore_color_callback(){printf('<input style="width: 100%%" class="color {hash:true, adjust:false, required:false}" type="text" id="wpns_current_fore_color" name="wpns_settings_preview[wpns_current_fore_color]" value="%s" />',esc_attr( $this->_options['wpns_current_fore_color']));}
	public function wpns_current_back_color_callback(){printf('<input style="width: 100%%" class="color {hash:true, adjust:false, required:false}" type="text" id="wpns_current_back_color" name="wpns_settings_preview[wpns_current_back_color]" value="%s" />',esc_attr( $this->_options['wpns_current_back_color']));}
	public function wpns_hover_fore_color_callback(){printf('<input style="width: 100%%" class="color {hash:true, adjust:false, required:false}" type="text" id="wpns_hover_fore_color" name="wpns_settings_preview[wpns_hover_fore_color]" value="%s" />',esc_attr( $this->_options['wpns_hover_fore_color']));}
	public function wpns_hover_back_color_callback(){printf('<input style="width: 100%%" class="color {hash:true, adjust:false, required:false}" type="text" id="wpns_hover_back_color" name="wpns_settings_preview[wpns_hover_back_color]" value="%s" />',esc_attr( $this->_options['wpns_hover_back_color']));}
	public function wpns_slider_color_callback(){printf('<input style="width: 100%%" class="color {hash:true, adjust:false, required:false}" type="text" id="wpns_slider_color" name="wpns_settings_preview[wpns_slider_color]" value="%s" />',esc_attr( $this->_options['wpns_slider_color']));}
	public function wpns_cursor_color_callback(){printf('<input style="width: 100%%" class="color {hash:true, adjust:false, required:false}" type="text" id="wpns_cursor_color" name="wpns_settings_preview[wpns_cursor_color]" value="%s" />',esc_attr( $this->_options['wpns_cursor_color']));}
	//Borders
	public function wpns_radius_callback(){printf('<input type="text" id="wpns_radius" name="wpns_settings_preview[wpns_radius]" value="%s" />',esc_attr( $this->_options['wpns_radius']));}
	public function wpns_page_border_callback(){printf('<input class="color {hash:true, adjust:true, required:false, borderstyle : true} type="text" id="wpns_page_border" name="wpns_settings_preview[wpns_page_border]" value="%s" />',esc_attr( $this->_options['wpns_page_border']));}
	public function wpns_current_border_callback(){printf('<input class="color {hash:true, adjust:true, required:false, borderstyle : true} type="text" id="wpns_current_border" name="wpns_settings_preview[wpns_current_border]" value="%s" />',esc_attr( $this->_options['wpns_current_border']));}
	public function wpns_hover_border_callback(){printf('<input class="color {hash:true, adjust:true, required:false, borderstyle : true} type="text" id="wpns_hover_border" name="wpns_settings_preview[wpns_hover_border]" value="%s" />',esc_attr( $this->_options['wpns_hover_border']));}
	public function wpns_slider_border_callback(){printf('<input class="color {hash:true, adjust:true, required:false, borderstyle : true} type="text" id="wpns_slider_border" name="wpns_settings_preview[wpns_slider_border]" value="%s" />',esc_attr( $this->_options['wpns_slider_border']));}
	public function wpns_cursor_border_callback(){printf('<input class="color {hash:true, adjust:true, required:false, borderstyle : true} type="text" id="wpns_cursor_border" name="wpns_settings_preview[wpns_cursor_border]" value="%s" />',esc_attr( $this->_options['wpns_cursor_border']));}
	//Auto display
	public function wpns_auto_display_callback(){printf('<input type="checkbox" id="wpns_auto_display" name="wpns_settings_preview[wpns_auto_display]" value="1"' . checked( 1,$this->_options['wpns_auto_display'],false) . '/>',esc_attr( $this->_options['wpns_auto_display']));}
	public function wpns_auto_display_position_callback(){
		printf('<select type="text" id="wpns_auto_display_position" name="wpns_settings_preview[wpns_auto_display_position]" value="%s" />',esc_attr( $this->_options['wpns_auto_display_position']));
		printf('<option value="footer top"'.selected( 'footer top',$this->_options['wpns_auto_display_position'],false).'>footer top</option>');
		printf('<option value="footer bottom"'.selected( 'footer bottom',$this->_options['wpns_auto_display_position'],false).'>footer bottom</option>');
		printf('</select>');
	}
}

if( is_admin() ) $wpns_settings_page = new WPNS_SETTING_PAGE($default_settings);


?>